---
 drivers/md/dm-thin.c |   20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

Index: linux/drivers/md/dm-thin.c
===================================================================
--- linux.orig/drivers/md/dm-thin.c
+++ linux/drivers/md/dm-thin.c
@@ -210,7 +210,7 @@ struct pool_c {
 
 	dm_block_t low_water_blocks;
 	struct pool_features initial_pf; /* initial features requested during table load */
-	struct pool_features pf;         /* actual features that were made live */
+	struct pool_features live_pf;    /* actual features that were made live */
 };
 
 /*
@@ -1489,7 +1489,7 @@ static void disable_passdown_if_not_supp
 	const char *reason = NULL;
 	char buf[BDEVNAME_SIZE];
 
-	if (!pt->pf.discard_passdown)
+	if (!pt->live_pf.discard_passdown)
 		return;
 
 	if (!data_dev_supports_discard(pt))
@@ -1506,7 +1506,7 @@ static void disable_passdown_if_not_supp
 
 	if (reason) {
 		DMWARN("Data device (%s) %s: Disabling discard passdown.", bdevname(data_bdev, buf), reason);
-		pt->pf.discard_passdown = false;
+		pt->live_pf.discard_passdown = false;
 	}
 }
 
@@ -1518,14 +1518,14 @@ static int bind_control_target(struct po
 	 * We want to make sure that degraded pools are never upgraded.
 	 */
 	enum pool_mode old_mode = pool->pf.mode;
-	enum pool_mode new_mode = pt->pf.mode;
+	enum pool_mode new_mode = pt->live_pf.mode;
 
 	if (old_mode > new_mode)
 		new_mode = old_mode;
 
 	pool->ti = ti;
 	pool->low_water_blocks = pt->low_water_blocks;
-	pool->pf = pt->pf;
+	pool->pf = pt->live_pf;
 
 	set_pool_mode(pool, new_mode);
 
@@ -1918,7 +1918,7 @@ static int pool_ctr(struct dm_target *ti
 	pt->metadata_dev = metadata_dev;
 	pt->data_dev = data_dev;
 	pt->low_water_blocks = low_water_blocks;
-	pt->pf = pt->initial_pf = pf;
+	pt->live_pf = pt->initial_pf = pf;
 	ti->num_flush_requests = 1;
 
 	/*
@@ -2405,7 +2405,7 @@ static void set_discard_limits(struct po
 
 	limits->max_discard_sectors = pool->sectors_per_block;
 
-	if (pt->pf.discard_passdown) {
+	if (pt->live_pf.discard_passdown) {
 		data_limits = &bdev_get_queue(pt->data_dev->bdev)->limits;
 		limits->discard_granularity = data_limits->discard_granularity;
 	} else if (block_size_is_power_of_two(pool))
@@ -2429,11 +2429,11 @@ static void pool_io_hints(struct dm_targ
 	blk_limits_io_opt(limits, pool->sectors_per_block << SECTOR_SHIFT);
 
 	/*
-	 * pt->pf is used here because it reflects the configured features that
-	 * will get transferred to the live pool in bind_control_target()
+	 * pt->live_pf is used here because it reflects the configured features
+	 * that will get transferred to the live pool in bind_control_target()
 	 * called from pool_preresume().
 	 */
-	if (!pt->pf.discard_enabled)
+	if (!pt->live_pf.discard_enabled)
 		return;
 
 	disable_passdown_if_not_supported(pt);
